==> vue-radio-2.21.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/radio/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconRadio, iconRadioselected, iconMobileRadio, iconMobileRadioSelected } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "radio-default": "radio inline-flex items-center align-middle leading-4 cursor-pointer sm:flex-row py-px sm:py-0 h-fit",
  "radio-label-common": "relative text-center w-7 h-7 mr-2 sm:mr-0",
  "radio-label-size-common": "sm:w-4 sm:h-4",
  "radio-label-size-medium": "sm:w-6 sm:h-6",
  "radio-label-circle": "inline-flex p-3 sm:p-0",
  "icon-common": "absolute top-1/2 left-1/2 -translate-x-1/2 -translate-y-1/2 z-0 transition-all",
  "icon-show": "opacity-100 scale-100 z-10",
  "icon-hidden": "opacity-0 scale-0 z-0",
  "icon-radioselected-common": "w-5 h-5 fill-color-bg-1 flex-1 [&_circle:nth-of-type(1)]:fill-color-bg-1",
  "icon-radioselected-size-common": "sm:w-4 sm:h-4",
  "icon-radioselected-size-medium": "sm:w-6 sm:h-6",
  "icon-radioselected-disabled": "fill-color-brand-disabled cursor-not-allowed [&_circle:nth-of-type(1)]:fill-color-bg-1",
  "icon-radioselected-default": "fill-color-brand [&_circle:nth-of-type(1)]:shadow-xsm",
  "icon-radio-common": "w-5 h-5 flex-1",
  "icon-radio-size-common": "sm:w-4 sm:h-4",
  "icon-radio-size-medium": "sm:w-6 sm:h-6",
  "icon-radio-default": "fill-color-bg-1 [&_path:nth-of-type(1)]:fill-color-icon-secondary",
  "icon-radio-disabled": "[&_path:nth-of-type(1)]:fill-color-icon-disabled [&_path:nth-of-type(2)]:fill-color-bg-3 cursor-not-allowed",
  "mobile-icon-radioselected-disabled": "fill-color-bg-1 [&_path:nth-of-type(1)]:fill-color-brand-disabled cursor-not-allowed",
  "mobile-icon-radioselected-default": "fill-color-bg-1 [&_path:nth-of-type(1)]:fill-color-brand [&_path:nth-of-type(1)]:shadow-xsm",
  "mobile-icon-radio-default": "[&_path:nth-of-type(2)]:fill-color-none-hover [&_path:nth-of-type(1)]:fill-color-bg-1",
  "mobile-icon-radio-disabled": "[&_path:nth-of-type(2)]:fill-color-icon-disabled [&_path:nth-of-type(1)]:fill-color-bg-3 cursor-not-allowed",
  "radio-input": "absolute left-0 right-0 top-0 bottom-0 w-0 h-0 -z-10 opacity-0",
  "radio-text-common": "sm:h-4 text-center text-color-text-primary align-middle text-sm",
  "radio-text-size-common": "sm:text-xs",
  "radio-text-size-medium": "sm:text-sm",
  "radio-hover": "sm:[&_path:nth-of-type(1)]:hover:fill-color-brand-hover",
  "radio-hover-selected": "sm:[&_path:nth-of-type(1)]:hover:fill-color-brand-hover",
  "radio-active": "sm:[&_path:nth-of-type(1)]:active:fill-color-brand-active",
  "radio-active-selected": "sm:[&_path:nth-of-type(1)]:active:fill-color-brand-active",
  "label-disabled": "text-color-text-secondary cursor-not-allowed",
  "pc-show": "hidden sm:block",
  "mobile-show": "block sm:hidden",
  "readonly-is-checked": "sm:m-0",
  "readonly-is-not-checked": "sm:hidden",
  "not-readonly-common": "mr-5 sm:[&:last-child]:mr-0",
  "hidden-radio": "sm:hidden",
  "not-readly-common-label": "sm:py-0 sm:pl-2 -ml-0.5 sm:ml-0",
  "readonly-checked-label": "sm:pl-0 text-color-text-primary",
  "verticalStyle": "sm:mb-2 sm:[&:last-child]:mb-0 sm:mr-0"
};
var __vue2_script = defineComponent({
  emits: ["change", "update:modelValue"],
  props: [].concat(props, ["modelValue", "events", "label", "text", "disabled", "name", "border", "size", "tabindex", "displayOnly"]),
  inheritAttrs: false,
  components: {
    IconRadio: iconRadio(),
    IconRadioselected: iconRadioselected(),
    IconMobileRadio: iconMobileRadio(),
    IconMobileRadioSelected: iconMobileRadioSelected()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("label", _vm._b({
    class: _vm.m(_vm.gcls("radio-default"), _vm.gcls(_vm.state.isDisplayOnly ? _vm.state.model === _vm.label ? "readonly-is-checked" : "readonly-is-not-checked" : "not-readonly-common"), _vm.gcls({
      "verticalStyle": _vm.state.vertical
    })),
    attrs: {
      "data-tag": "tiny-radio",
      "role": "radio",
      "aria-checked": _vm.state.model === _vm.label,
      "aria-disabled": _vm.state.isDisabled,
      "tabindex": "-1"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"])) return null;
        $event.stopPropagation();
        $event.preventDefault();
        _vm.state.model = _vm.state.isDisabled ? _vm.state.model : _vm.label;
      }
    }
  }, "label", _vm.a(_vm.$attrs, ["class", "style", "onClick"], true), false), [_c("span", {
    class: _vm.m(_vm.gcls("radio-label-common"), _vm.gcls(_vm.state.size === "medium" ? "radio-label-size-medium" : "radio-label-size-common"), _vm.gcls(_vm.state.isDisplayOnly && _vm.state.model === _vm.label && "hidden-radio")),
    attrs: {
      "data-tag": "tiny-radio-content"
    }
  }, [_c("span", {
    class: _vm.m(_vm.gcls("radio-label-circle")),
    attrs: {
      "data-tag": "tiny-radio-icon",
      "tabindex": _vm.tabindex
    }
  }, [_c("icon-radio", {
    class: _vm.m(_vm.gcls("icon-common"), _vm.gcls("pc-show"), _vm.gcls({
      "radio-active": !_vm.state.isDisabled
    }), _vm.gcls({
      "radio-hover": !_vm.state.isDisabled
    }), _vm.gcls({
      "icon-radio-disabled": _vm.state.isDisabled
    }), _vm.gcls({
      "icon-radio-default": !_vm.state.isDisabled
    }), _vm.gcls("icon-radio-common"), _vm.gcls(_vm.state.size === "medium" ? "icon-radio-size-medium" : "icon-radio-size-common"))
  }), _c("icon-radioselected", {
    class: _vm.m(_vm.gcls("icon-common"), _vm.gcls("pc-show"), _vm.state.model === _vm.label ? _vm.gcls("icon-show") : _vm.gcls("icon-hidden"), _vm.gcls({
      "radio-hover-selected": !_vm.state.isDisabled
    }), _vm.gcls({
      "radio-active-selected": !_vm.state.isDisabled
    }), _vm.gcls("icon-radioselected-common"), _vm.gcls({
      "icon-radioselected-disabled": _vm.state.isDisabled
    }), _vm.gcls({
      "icon-radioselected-default": !_vm.state.isDisabled
    }), _vm.gcls(_vm.state.size === "medium" ? "icon-radioselected-size-medium" : "icon-radioselected-size-common"))
  }), _c("icon-mobile-radio", {
    class: _vm.m(_vm.gcls("icon-common"), _vm.gcls("mobile-show"), _vm.gcls({
      "mobile-icon-radio-disabled": _vm.state.isDisabled
    }), _vm.gcls({
      "mobile-icon-radio-default": !_vm.state.isDisabled
    }), _vm.gcls("icon-radio-common"))
  }), _c("icon-mobile-radio-selected", {
    class: _vm.m(_vm.gcls("icon-common"), _vm.gcls("mobile-show"), _vm.state.model === _vm.label ? _vm.gcls("icon-show") : _vm.gcls("icon-hidden"), _vm.gcls("icon-radioselected-common"), _vm.gcls({
      "mobile-icon-radioselected-disabled": _vm.state.isDisabled
    }), _vm.gcls({
      "mobile-icon-radioselected-default": !_vm.state.isDisabled
    }))
  })], 1), _c("input", {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.state.model,
      expression: "state.model"
    }],
    ref: "radio",
    class: _vm.m(_vm.gcls("radio-input")),
    attrs: {
      "type": "radio",
      "name": _vm.name,
      "disabled": _vm.state.isDisabled
    },
    domProps: {
      "value": _vm.label,
      "checked": _vm._q(_vm.state.model, _vm.label)
    },
    on: {
      "focus": function focus($event) {
        _vm.state.focus = true;
      },
      "blur": function blur($event) {
        _vm.state.focus = false;
      },
      "change": [function($event) {
        return _vm.$set(_vm.state, "model", _vm.label);
      }, _vm.handleChange],
      "click": function click($event) {
        $event.stopPropagation();
      }
    }
  })]), _c("span", {
    ref: "label",
    class: _vm.m(_vm.gcls("radio-text-common"), _vm.gcls(_vm.state.size !== "mini" ? "radio-text-size-medium" : "radio-text-size-common"), _vm.gcls({
      "label-disabled": _vm.state.isDisabled
    }), _vm.gcls(_vm.state.isDisplayOnly ? _vm.state.model === _vm.label ? "readonly-checked-label" : "" : "not-readly-common-label")),
    attrs: {
      "data-tag": "tiny-radio-label"
    },
    on: {
      "keydown": function keydown($event) {
        $event.stopPropagation();
      }
    }
  }, [_vm._t("default", function() {
    return [_vm._v(_vm._s(_vm.text || _vm.label))];
  })], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };

==> vue-radio-2.22.1.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/radio/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconRadio, iconRadioselected, iconMobileRadio, iconMobileRadioSelected } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "radio-default": "radio inline-flex items-center  leading-4 cursor-pointer sm:flex-row py-px sm:py-0 h-fit",
  "radio-label-common": "relative text-center w-7 h-7 mr-2 sm:mr-0",
  "radio-label-size-common": "sm:w-4 sm:h-4",
  "radio-label-size-medium": "sm:w-6 sm:h-6",
  "radio-label-circle": "inline-flex p-3 sm:p-0",
  "icon-common": "absolute top-1/2 left-1/2 -translate-x-1/2 -translate-y-1/2 z-0 transition-all",
  "icon-show": "opacity-100 scale-100 z-10",
  "icon-hidden": "opacity-0 scale-0 z-0",
  "icon-radioselected-common": "w-5 h-5 fill-color-bg-1 flex-1 [&_circle:nth-of-type(1)]:fill-color-bg-1",
  "icon-radioselected-size-common": "sm:w-4 sm:h-4",
  "icon-radioselected-size-medium": "sm:w-6 sm:h-6",
  "icon-radioselected-disabled": "fill-color-brand-disabled cursor-not-allowed [&_circle:nth-of-type(1)]:fill-color-bg-1",
  "icon-radioselected-default": "fill-color-brand [&_circle:nth-of-type(1)]:shadow-xsm",
  "icon-radio-common": "w-5 h-5 flex-1",
  "icon-radio-size-common": "sm:w-4 sm:h-4",
  "icon-radio-size-medium": "sm:w-6 sm:h-6",
  "icon-radio-default": "fill-color-bg-1 [&_path:nth-of-type(1)]:fill-color-icon-secondary",
  "icon-radio-disabled": "[&_path:nth-of-type(1)]:fill-color-icon-disabled [&_path:nth-of-type(2)]:fill-color-bg-3 cursor-not-allowed",
  "mobile-icon-radioselected-disabled": "fill-color-bg-1 [&_path:nth-of-type(1)]:fill-color-brand-disabled cursor-not-allowed",
  "mobile-icon-radioselected-default": "fill-color-bg-1 [&_path:nth-of-type(1)]:fill-color-brand [&_path:nth-of-type(1)]:shadow-xsm",
  "mobile-icon-radio-default": "[&_path:nth-of-type(2)]:fill-color-none-hover [&_path:nth-of-type(1)]:fill-color-bg-1",
  "mobile-icon-radio-disabled": "[&_path:nth-of-type(2)]:fill-color-icon-disabled [&_path:nth-of-type(1)]:fill-color-bg-3 cursor-not-allowed",
  "radio-input": "absolute left-0 right-0 top-0 bottom-0 w-0 h-0 -z-10 opacity-0",
  "radio-text-common": "sm:h-4 text-color-text-primary align-middle text-sm",
  "radio-text-size-common": "sm:text-xs",
  "radio-text-size-medium": "sm:text-sm",
  "radio-hover": "sm:[&_path:nth-of-type(1)]:hover:fill-color-brand-hover",
  "radio-hover-selected": "sm:[&_path:nth-of-type(1)]:hover:fill-color-brand-hover",
  "radio-active": "sm:[&_path:nth-of-type(1)]:active:fill-color-brand-active",
  "radio-active-selected": "sm:[&_path:nth-of-type(1)]:active:fill-color-brand-active",
  "label-disabled": "text-color-text-secondary cursor-not-allowed",
  "pc-show": "hidden sm:block",
  "mobile-show": "block sm:hidden",
  "readonly-is-checked": "sm:m-0 cursor-default",
  "readonly-is-not-checked": "sm:hidden cursor-default",
  "not-readonly-common": "mr-5 align-middle sm:[&:last-child]:mr-0",
  "hidden-radio": "sm:hidden",
  "not-readly-common-label": "sm:py-0 sm:pl-2 -ml-0.5 sm:ml-0",
  "readonly-checked-label": "sm:pl-0 text-color-text-primary",
  "verticalStyle": "sm:mb-2 sm:[&:last-child]:mb-0 sm:mr-0"
};
var __vue2_script = defineComponent({
  emits: ["change", "update:modelValue"],
  props: [].concat(props, ["modelValue", "events", "label", "text", "disabled", "name", "border", "size", "tabindex", "displayOnly"]),
  inheritAttrs: false,
  components: {
    IconRadio: iconRadio(),
    IconRadioselected: iconRadioselected(),
    IconMobileRadio: iconMobileRadio(),
    IconMobileRadioSelected: iconMobileRadioSelected()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("label", _vm._b({
    class: _vm.m(_vm.gcls("radio-default"), _vm.gcls(_vm.state.isDisplayOnly ? _vm.state.model === _vm.label ? "readonly-is-checked" : "readonly-is-not-checked" : "not-readonly-common"), _vm.gcls({
      "verticalStyle": _vm.state.vertical
    })),
    attrs: {
      "data-tag": "tiny-radio",
      "role": "radio",
      "aria-checked": _vm.state.model === _vm.label,
      "aria-disabled": _vm.state.isDisabled,
      "tabindex": "-1"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"])) return null;
        $event.stopPropagation();
        $event.preventDefault();
        _vm.state.model = _vm.state.isDisabled ? _vm.state.model : _vm.label;
      }
    }
  }, "label", _vm.a(_vm.$attrs, ["class", "style", "onClick"], true), false), [_c("span", {
    class: _vm.m(_vm.gcls("radio-label-common"), _vm.gcls(_vm.state.size === "medium" ? "radio-label-size-medium" : "radio-label-size-common"), _vm.gcls(_vm.state.isDisplayOnly && _vm.state.model === _vm.label && "hidden-radio")),
    attrs: {
      "data-tag": "tiny-radio-content"
    }
  }, [_c("span", {
    class: _vm.m(_vm.gcls("radio-label-circle")),
    attrs: {
      "data-tag": "tiny-radio-icon",
      "tabindex": _vm.tabindex
    }
  }, [_c("icon-radio", {
    class: _vm.m(_vm.gcls("icon-common"), _vm.gcls("pc-show"), _vm.gcls({
      "radio-active": !_vm.state.isDisabled
    }), _vm.gcls({
      "radio-hover": !_vm.state.isDisabled
    }), _vm.gcls({
      "icon-radio-disabled": _vm.state.isDisabled
    }), _vm.gcls({
      "icon-radio-default": !_vm.state.isDisabled
    }), _vm.gcls("icon-radio-common"), _vm.gcls(_vm.state.size === "medium" ? "icon-radio-size-medium" : "icon-radio-size-common"))
  }), _c("icon-radioselected", {
    class: _vm.m(_vm.gcls("icon-common"), _vm.gcls("pc-show"), _vm.state.model === _vm.label ? _vm.gcls("icon-show") : _vm.gcls("icon-hidden"), _vm.gcls({
      "radio-hover-selected": !_vm.state.isDisabled
    }), _vm.gcls({
      "radio-active-selected": !_vm.state.isDisabled
    }), _vm.gcls("icon-radioselected-common"), _vm.gcls({
      "icon-radioselected-disabled": _vm.state.isDisabled
    }), _vm.gcls({
      "icon-radioselected-default": !_vm.state.isDisabled
    }), _vm.gcls(_vm.state.size === "medium" ? "icon-radioselected-size-medium" : "icon-radioselected-size-common"))
  }), _c("icon-mobile-radio", {
    class: _vm.m(_vm.gcls("icon-common"), _vm.gcls("mobile-show"), _vm.gcls({
      "mobile-icon-radio-disabled": _vm.state.isDisabled
    }), _vm.gcls({
      "mobile-icon-radio-default": !_vm.state.isDisabled
    }), _vm.gcls("icon-radio-common"))
  }), _c("icon-mobile-radio-selected", {
    class: _vm.m(_vm.gcls("icon-common"), _vm.gcls("mobile-show"), _vm.state.model === _vm.label ? _vm.gcls("icon-show") : _vm.gcls("icon-hidden"), _vm.gcls("icon-radioselected-common"), _vm.gcls({
      "mobile-icon-radioselected-disabled": _vm.state.isDisabled
    }), _vm.gcls({
      "mobile-icon-radioselected-default": !_vm.state.isDisabled
    }))
  })], 1), _c("input", {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.state.model,
      expression: "state.model"
    }],
    ref: "radio",
    class: _vm.m(_vm.gcls("radio-input")),
    attrs: {
      "type": "radio",
      "name": _vm.name,
      "disabled": _vm.state.isDisabled
    },
    domProps: {
      "value": _vm.label,
      "checked": _vm._q(_vm.state.model, _vm.label)
    },
    on: {
      "focus": function focus($event) {
        _vm.state.focus = true;
      },
      "blur": function blur($event) {
        _vm.state.focus = false;
      },
      "change": [function($event) {
        return _vm.$set(_vm.state, "model", _vm.label);
      }, _vm.handleChange],
      "click": function click($event) {
        $event.stopPropagation();
      }
    }
  })]), _c("span", {
    ref: "label",
    class: _vm.m(_vm.gcls("radio-text-common"), _vm.gcls(_vm.state.size !== "mini" ? "radio-text-size-medium" : "radio-text-size-common"), _vm.gcls({
      "label-disabled": _vm.state.isDisabled
    }), _vm.gcls(_vm.state.isDisplayOnly ? _vm.state.model === _vm.label ? "readonly-checked-label" : "" : "not-readly-common-label")),
    attrs: {
      "data-tag": "tiny-radio-label"
    },
    on: {
      "keydown": function keydown($event) {
        $event.stopPropagation();
      }
    }
  }, [_vm._t("default", function() {
    return [_vm._v(_vm._s(_vm.text || _vm.label))];
  })], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
